import wepy from 'wepy';

export default class navMixin extends wepy.mixin {
  /**
   * 跳转到游戏信息页面
   * @param {string} gid 游戏短id
   * */
  $toGameInfo(gid) {
    wepy.navigateTo({
      url: '/pages/gameInfo?id=' + gid
    })
  }
  /**
   * 跳转到电影信息页面
   * @param {string} gid 电影短id
   * */
  $toMovieInfo(gid) {
    wepy.navigateTo({
      url: '/pages/movieInfo?id=' + gid
    })
  }
  /**
   * 跳转到合集页面
   * @param {string} gid 合集id
   * */
  $toCollectionInfo(gid) {
    wepy.navigateTo({
      url: '/pages/collection?id=' + gid
    })
  }
  /**
   * 跳转到历史记录页面
   * @param {string} dataType 数据类型 movie: 电影 game：游戏
   * @param {string} type 列表类型 history: 历史记录，owner: 已拥有记录
   * */
  $toHistory(dataType, type = 'history') {
    wepy.navigateTo({
      url: `/pages/history?dataType=${dataType}&type=${type}`
    })
  }
  // 跳转到登录公众号页面
  $toMpLogin() {
    wepy.redirectTo({
      url: '/pages/login'
    })
  }

  /**
   * 视频播放页面
   * @param {string} link 视频地址
   * @param {string} title 页面标题，可为空
   * */
  $toMovieMore(link, title) {
    wepy.navigateTo({
      url: '/pages/movieMore?link=' + encodeURIComponent(link) + '&title=' + encodeURIComponent(title)
    })
  }
  /**
   * 电影播放页面
   * @param {string} movieUrl 视频地址
   * @param {string} title 页面标题，可为空
   * */
  $toMovie(movieUrl, title) {
    let obj = `{"url": "${movieUrl}","name":"${title}"}`;
    const link = `${this.$getMovieUrl()}?param=${encodeURIComponent(obj)}`;
    wepy.navigateTo({
      url: '/pages/webview?link=' + encodeURIComponent(link) + '&title=' + encodeURIComponent(title)
    })
  }
  /**
   * 加载一个普通的网页
   * @param {string} url 网页地址
   * */
  $toWebView(url) {
    wepy.navigateTo({
      url: '/pages/webview?link=' + encodeURIComponent(url) + '&title='
    })
  }
  // "我"
  $toUser() {
    let pages = getCurrentPages();
    let pageUrl = 'pages/user';
    const index = pages.findIndex(o => o.route === pageUrl);
    if (index >= 0) {
      wepy.navigateBack({
        delta: (pages.length - index - 1)
      })
    } else {
      wepy.navigateTo({
        url: '/' + pageUrl
      })
    }
  }
  $backToIndex() {
    let pages = getCurrentPages();
    let pageUrl = 'pages/index';
    const index = pages.findIndex(o => o.route === pageUrl);
    if (index >= 0) {
      wepy.navigateBack({
        delta: (pages.length - index - 1)
      })
    } else {
      wepy.navigateTo({
        url: '/' + pageUrl
      })
    }
  }
  /**
   * 跳转到搜索页面
   * */
  $toSearch() {
    let pageUrl;
    switch (global.dataType) {
      case 'movie':
        pageUrl = 'pages/searchMovie'
        break;
      default:
        pageUrl = 'pages/search';
        break;
    }
    let pages = getCurrentPages();
    const index = pages.findIndex(o => o.route === pageUrl);
    if (index >= 0) {
      wepy.navigateBack({
        delta: (pages.length - index - 1)
      })
    } else {
      wepy.navigateTo({
        url: '/' + pageUrl
      })
    }
  }
  /**
   * 跳转到小游戏跳转页面，以获取金币
   * */
  $toJumpPage(aid, title) {
    wepy.navigateTo({
      url: `/pages/jumppage?text=${title}&aid=${aid}`
    });
  }

  $toArticle(id) {
    wepy.navigateTo({
      url: `/pages/article?id=${id}`
    });
  }

  $recordTap(data) {
    switch (data.type) {
      case 0:
        this.$toGameInfo(data.gid);
        break;
      case 2:
        this.$toMovieInfo(data.gid);
        break;
      case 1:
        this.$toWebView(data.link);
        break;
      case 5:
        this.$toCollectionInfo(data.gid);
        break;
      default:
        if (data.dataType === 'game') {
          this.$toGameInfo(data.gid);
        } else if (data.dataType === 'movie') {
          this.$toMovieInfo(data.gid);
        }
        break;
    }
  }
}
